from setuptools import setup, find_packages

setup(
    name='use_storage',
    version='0.1.1',
    description='A package for storing key-value data with backup history.',
    author='xilin',
    author_email='infinite357@gmail.com',
    packages=find_packages(),
    install_requires=[],
    python_requires='>=3.6',
)
